<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Utente:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Cadenza</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Massimo</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="234"/>
        <source>Supported files</source>
        <translation>File supportati</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="235"/>
        <source>CSV files</source>
        <translation>File CSV</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="236"/>
        <source>CUP files</source>
        <translation>File CUP</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="237"/>
        <source>FIT files</source>
        <translation>File FIT</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="238"/>
        <source>GeoJSON files</source>
        <translation>File GeoJSON</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="239"/>
        <source>GPI files</source>
        <translation>File GPI</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="240"/>
        <source>GPX files</source>
        <translation>File GPX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="241"/>
        <source>IGC files</source>
        <translation>File IGC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="242"/>
        <source>ITN files</source>
        <translation>File ITN</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="243"/>
        <source>JPEG images</source>
        <translation>File JPEG</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="244"/>
        <source>KML files</source>
        <translation>File KML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="245"/>
        <source>LOC files</source>
        <translation>File LOC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="246"/>
        <source>NMEA files</source>
        <translation>File NMEA</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="247"/>
        <source>ONmove files</source>
        <translation>File ONmove</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="248"/>
        <source>OV2 files</source>
        <translation>File OV2</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="249"/>
        <source>OziExplorer files</source>
        <translation>File OziExplorer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="250"/>
        <source>SLF files</source>
        <translation>File SLF</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="251"/>
        <source>SML files</source>
        <translation>File SML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="252"/>
        <source>TCX files</source>
        <translation>File TCX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="253"/>
        <source>70mai GPS log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="254"/>
        <source>VKX files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="255"/>
        <source>VTK files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="256"/>
        <source>TwoNav files</source>
        <translation>File TwoNav</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="257"/>
        <source>GPSDump files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="258"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Configurazione predefinita</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Seleziona cartella</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Altitudine</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Salita</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Discesa</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minima</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>Salita</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>Discesa</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>Minima</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Seleziona file</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Nessun file di output selezionato.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 è una cartella.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 non è scrivibile.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <location filename="../src/GUI/format.cpp" line="93"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <location filename="../src/GUI/format.cpp" line="60"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="67"/>
        <location filename="../src/GUI/format.cpp" line="70"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="74"/>
        <location filename="../src/GUI/format.cpp" line="90"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="77"/>
        <location filename="../src/GUI/format.cpp" line="80"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="200"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="208"/>
        <location filename="../src/GUI/gui.cpp" line="975"/>
        <location filename="../src/GUI/gui.cpp" line="993"/>
        <source>Paths</source>
        <translation>Percorsi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="212"/>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <location filename="../src/GUI/gui.cpp" line="936"/>
        <source>Keyboard controls</source>
        <translation>Scorciatoie da tastiera</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="216"/>
        <location filename="../src/GUI/gui.cpp" line="902"/>
        <source>About GPXSee</source>
        <translation>A proposito di GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="222"/>
        <source>Open...</source>
        <translation>Apri...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="229"/>
        <source>Open directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="234"/>
        <source>Print...</source>
        <translation>Stampa...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="240"/>
        <source>Export to PDF...</source>
        <translation>Esporta in PDF...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="247"/>
        <source>Export to PNG...</source>
        <translation>Esporta in PNG...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="254"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="261"/>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="267"/>
        <source>Statistics...</source>
        <translation>Statistiche...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="277"/>
        <source>Clear list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="289"/>
        <source>Load POI file...</source>
        <translation>Carica file POI...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="293"/>
        <source>Select all files</source>
        <translation>Seleziona tutti i file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="298"/>
        <source>Unselect all files</source>
        <translation>Deseleziona tutti i file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="303"/>
        <source>Overlap POIs</source>
        <translation>Sovrapponi POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="308"/>
        <source>Show POI icons</source>
        <translation>Mostra icone POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="313"/>
        <source>Show POI labels</source>
        <translation>Mostra etichette POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="319"/>
        <source>Show POIs</source>
        <translation>Mostra POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="331"/>
        <source>Show map</source>
        <translation>Mostra mappa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="340"/>
        <source>Load map...</source>
        <translation>Carica mappa...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="345"/>
        <source>Load map directory...</source>
        <translation>Carica la directory della mappa…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="348"/>
        <source>Clear tile cache</source>
        <translation>Cancella cache mappe</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="353"/>
        <location filename="../src/GUI/gui.cpp" line="358"/>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <source>Next map</source>
        <translation>Mappa successiva</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="363"/>
        <source>Show cursor coordinates</source>
        <translation>Mostra coordinate del cursore</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="371"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="375"/>
        <source>Raster only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="379"/>
        <source>Vector only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="386"/>
        <source>Show position</source>
        <translation>Visualizza posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="392"/>
        <source>Follow position</source>
        <translation>Segui posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="397"/>
        <source>Show coordinates</source>
        <translation>Visualizza coordinate</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show motion info</source>
        <translation>Visualizza informazioni movimento</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="410"/>
        <source>Show tracks</source>
        <translation>Mostra tracce</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="415"/>
        <source>Show routes</source>
        <translation>Mostra percorso</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="420"/>
        <source>Show waypoints</source>
        <translation>Mostra punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="426"/>
        <source>Show areas</source>
        <translation>Mostra aree</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="431"/>
        <source>Waypoint icons</source>
        <translation>Icone punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="436"/>
        <source>Waypoint labels</source>
        <translation>Etichette punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="441"/>
        <source>Route waypoints</source>
        <translation>Punti del percorso</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="446"/>
        <source>km/mi markers</source>
        <translation>Pietre miliari</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="454"/>
        <source>Do not show</source>
        <translation>Non mostrare</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Marker only</source>
        <translation>Solo indicatori</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="462"/>
        <source>Date/time</source>
        <translation>Data e ora</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="466"/>
        <source>Coordinates</source>
        <translation>Coordinate</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="470"/>
        <source>Use styles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <source>Show local DEM tiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="491"/>
        <source>Show hillshading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="499"/>
        <source>Show graphs</source>
        <translation>Mostra grafici</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="507"/>
        <location filename="../src/GUI/gui.cpp" line="1445"/>
        <location filename="../src/GUI/gui.cpp" line="1505"/>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="514"/>
        <location filename="../src/GUI/gui.cpp" line="764"/>
        <location filename="../src/GUI/gui.cpp" line="1447"/>
        <location filename="../src/GUI/gui.cpp" line="1507"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="520"/>
        <source>Show grid</source>
        <translation>Mostra griglia</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="525"/>
        <source>Show slider info</source>
        <translation>Mostra informazioni cursore</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="531"/>
        <source>Show tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Show toolbars</source>
        <translation>Mostra barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="547"/>
        <source>Total time</source>
        <translation>Tempo totale</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="552"/>
        <location filename="../src/GUI/gui.cpp" line="1448"/>
        <location filename="../src/GUI/gui.cpp" line="1509"/>
        <source>Moving time</source>
        <translation>Tempo in movimento</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Metric</source>
        <translation>Metrico</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="564"/>
        <source>Imperial</source>
        <translation>Imperiale</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="570"/>
        <source>Nautical</source>
        <translation>Nautico</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="578"/>
        <source>Decimal degrees (DD)</source>
        <translation>Gradi decimali (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="584"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Gradi e minuti decimali (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="591"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Gradi, minuti e secondi (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Fullscreen mode</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="605"/>
        <source>Options...</source>
        <translation>Opzioni...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="612"/>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="617"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="622"/>
        <source>Last</source>
        <translation>Ultimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="627"/>
        <source>First</source>
        <translation>Primo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="662"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="665"/>
        <source>Open recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="690"/>
        <source>&amp;Map</source>
        <translation>&amp;Mappa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="696"/>
        <source>Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="705"/>
        <source>&amp;Graph</source>
        <translation>&amp;Grafico</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="736"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="756"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <location filename="../src/GUI/gui.cpp" line="1000"/>
        <source>CRS directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="988"/>
        <location filename="../src/GUI/gui.cpp" line="1006"/>
        <source>Symbols directory:</source>
        <translation>Cartella simboli</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1054"/>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1126"/>
        <source>Error loading geo URI:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1132"/>
        <location filename="../src/GUI/gui.cpp" line="1172"/>
        <location filename="../src/GUI/gui.cpp" line="1865"/>
        <location filename="../src/GUI/gui.cpp" line="1971"/>
        <source>Don&apos;t show again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2034"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2057"/>
        <source>Download %n DEM tiles?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="717"/>
        <source>&amp;Data</source>
        <translation>&amp;Dati</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="477"/>
        <source>Download data DEM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="483"/>
        <source>Download map DEM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="722"/>
        <source>Position info</source>
        <translation>Info sulla posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="748"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="763"/>
        <source>&amp;Settings</source>
        <translation>Impo&amp;stazioni</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="768"/>
        <source>Units</source>
        <translation>Unità</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="773"/>
        <source>Coordinates format</source>
        <translation>Formato coordinate</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="786"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="813"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="823"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="831"/>
        <source>Navigation</source>
        <translation>Navigazione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="904"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Version %1</source>
        <translation>Versione %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="907"/>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee è distribuito sotto i termini della GNU General Public License versione 3. Per maggiori informazioni su GPXSee visitare il sito del progetto %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Next file</source>
        <translation>File successivo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Previous file</source>
        <translation>File precedente</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="942"/>
        <source>First file</source>
        <translation>Primo file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Last file</source>
        <translation>Ultimo file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="945"/>
        <source>Append file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="946"/>
        <source>Next/Previous</source>
        <translation>Successivo/Precedente</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="948"/>
        <source>Toggle graph type</source>
        <translation>Cambia formato del grafico</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="950"/>
        <source>Toggle time type</source>
        <translation>Cambia formato del tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="952"/>
        <source>Toggle position info</source>
        <translation>Attiva/disattiva le informazioni posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Previous map</source>
        <translation>Mappa precedente</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="957"/>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="959"/>
        <source>Zoom out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Digital zoom</source>
        <translation>Zoom digitale</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Copy coordinates</source>
        <translation>Copia le coordinate</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <source>Left Click</source>
        <translation>Clic sinistro</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <location filename="../src/GUI/gui.cpp" line="996"/>
        <source>Map directory:</source>
        <translation>Cartella mappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>POI directory:</source>
        <translation>Cartella POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <location filename="../src/GUI/gui.cpp" line="1002"/>
        <source>DEM directory:</source>
        <translation>Cartella DEM:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="986"/>
        <location filename="../src/GUI/gui.cpp" line="1004"/>
        <source>Styles directory:</source>
        <translation>Cartella stili:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="990"/>
        <location filename="../src/GUI/gui.cpp" line="1008"/>
        <source>Tile cache directory:</source>
        <translation>Cartella cache mappe:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1019"/>
        <location filename="../src/GUI/gui.cpp" line="1022"/>
        <source>Open file</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1164"/>
        <source>Error loading data file:</source>
        <translation>Errore caricamento file:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1167"/>
        <location filename="../src/GUI/gui.cpp" line="1283"/>
        <source>Line: %1</source>
        <translation>Linea: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1250"/>
        <location filename="../src/GUI/gui.cpp" line="1253"/>
        <source>Open POI file</source>
        <translation>Apri file POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1280"/>
        <source>Error loading POI file:</source>
        <translation>Errore caricamento file POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1427"/>
        <location filename="../src/GUI/gui.cpp" line="1485"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1429"/>
        <location filename="../src/GUI/gui.cpp" line="1487"/>
        <source>Routes</source>
        <translation>Percorsi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <location filename="../src/GUI/gui.cpp" line="1489"/>
        <source>Waypoints</source>
        <translation>Punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1433"/>
        <location filename="../src/GUI/gui.cpp" line="1491"/>
        <source>Areas</source>
        <translation>Aree</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <location filename="../src/GUI/gui.cpp" line="1439"/>
        <location filename="../src/GUI/gui.cpp" line="1496"/>
        <location filename="../src/GUI/gui.cpp" line="1498"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1460"/>
        <location filename="../src/GUI/gui.cpp" line="1463"/>
        <location filename="../src/GUI/gui.cpp" line="1464"/>
        <source>Statistics</source>
        <translation>Statistiche</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1481"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1804"/>
        <location filename="../src/GUI/gui.cpp" line="1807"/>
        <source>Open map file</source>
        <translation>Apri file mappa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1859"/>
        <location filename="../src/GUI/gui.cpp" line="1922"/>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <location filename="../src/GUI/gui.cpp" line="1965"/>
        <source>Error loading map:</source>
        <translation>Errore caricamento mappa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2005"/>
        <source>Select map directory</source>
        <translation>Seleziona la directory mappa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2054"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2070"/>
        <source>Could not download all required DEM files.</source>
        <translation>Impossibile scaricare tutti i file DEM.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2087"/>
        <source>No local DEM tiles found.</source>
        <translation>Nessun file DEM trovato.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2101"/>
        <source>No files loaded</source>
        <translation>Nessun file caricato</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2105"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n file</numerusform>
            <numerusform>%n file</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Rapporto marce</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Più usati</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Massimo</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>Massimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>Più usato</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="67"/>
        <source>Data not available</source>
        <translation>Dati non disponibili</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="86"/>
        <location filename="../src/GUI/graphview.cpp" line="191"/>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="123"/>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="126"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="148"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="151"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="154"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="193"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Frequenza cardiaca</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>Massimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>File</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>File supportati</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>Mappe AlpineQuest</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Mappe Garmin IMG</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Mappe Garmin JNX</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>Carte nautiche BSB</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>Mappe KMZ</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mappe Mapsforge</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>Mappe OziExplorer</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>Mappe MBTiles</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>Mappe/Atlanti TrekBuddy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>Immagini GeoTIFF</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>Mappe TwoNav</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Mappe Locus/OsmAnd/RMaps o SQLite</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Mappe online</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>Le mappe non HiDPI sono caricate come HiDPI. La mappa appare nitida, ma gli oggetti sono più piccoli e più difficili da leggere.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>Le mappe non HiDPI sono caricate così come sono. Gli oggetti conservano la loro dimensione, ma la mappa appare sfocata.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>Ingresso</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>Uscita</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>Ingresso:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>Uscita:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>Proiezione</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation>Modalità di visualizzazione HiDPI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>Larghezza traccia:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>Stile traccia:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>Stile:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>Larghezza percorso:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>Stile percorso:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>Percorsi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>Larghezza bordo area:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>Stile bordo area:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>Opacità riempimento area:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>Aree</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>Colore base:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation>Spostamento tavolozza:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>Usa anti-alias</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>Colore punto:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>Dimensione punto:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>Punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>Colore POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>Dimensione POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>Larghezza linea:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>Colore del cursore:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>Colore di sfondo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>Percorsi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>Punti</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Graphs</source>
        <translation>Grafici</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation>Dimensione finestra media mobile</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>Altitudine:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>Velocità:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>Frequenza cardiaca:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>Cadenza:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>Potenza:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>Smoothing</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation>Elimina outliers GPS</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>Velocità minima:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>Durata minima:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>Calcolata come spazio/tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>Registrata dal dispositivo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>Mostra velocità secondaria</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>Dati GPS</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>Dati DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>Mostra altitudine secondaria</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="842"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>Usa segmenti</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>Fuso orario:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>Altitudine</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>Fuso orario</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>Sorgenti</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>Riconoscimento pause</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>Raggio:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>Usa HTTP autentificazione</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="685"/>
        <source>Plugin:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="703"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>High-Resolution</source>
        <translation>Alta risoluzione</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="709"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>L&apos;area stampata corrisponde approssimativamente all&apos;area mostrata. Il livello di zoom della mappa non cambia.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="711"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>Il livello di zoom viene cambiato, in modo che tutto il contenuto (tracce/tappe) rientri nell&apos;area di stampa, e che la risoluzione della mappa sia più vicina possibile alla risoluzione di stampa.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="727"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="729"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Moving time</source>
        <translation>Tempo in movimento</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Item count (&gt;1)</source>
        <translation>Numero elementi (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="752"/>
        <source>Separate graph page</source>
        <translation>Pagina separata per i grafici</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="762"/>
        <source>Print mode</source>
        <translation>Modalità di stampa</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="763"/>
        <source>Header</source>
        <translation>Intestazione</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="771"/>
        <source>Use OpenGL</source>
        <translation>Usa OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="773"/>
        <source>Enable HTTP/2</source>
        <translation>Abilita HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="779"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="785"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="797"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="805"/>
        <source>Image cache size:</source>
        <translation>Dimensione cache immagini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="807"/>
        <source>Connection timeout:</source>
        <translation>Timeout connessione:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="806"/>
        <source>DEM cache size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="826"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Data:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="831"/>
        <source>Maps:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="832"/>
        <source>POI:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="843"/>
        <source>Initial paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="881"/>
        <source>Maps</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Data</source>
        <translation>Dati</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>DEM</source>
        <translation type="unfinished">DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="889"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="891"/>
        <source>Print &amp; Export</source>
        <translation>Stampa e esporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="926"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>File PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Ritratto (Portrait)</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Paesaggio</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Impostazioni pagina</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Dimensioni pagina:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Risoluzione:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Orientamento:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Margini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Output file</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Esporta in PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>File PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Usa anti-alias</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Configurazione immagine</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Larghezza immagine:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Altezza immagine:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Margini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Output file</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Esporta in PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Potenza</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation type="unfinished">File</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Ritmo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>Ritmo</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>Massima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>Minima</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Tempo totale</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Tempo in movimento</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation type="unfinished">File</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>Coordinate</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>Altitudine</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>Telefono</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>Collegamenti</translation>
    </message>
</context>
</TS>
